@@ -4,9 +4,11 @@
 #![feature(llvm_asm)]
 
 /// Library for ATmega2560P chip.
+#[cfg(feature = "atmega2560p")]
 pub mod atmega2560p {
 
     /// Hardware Abstraction Library (HAL).
+    #[cfg(feature = "atmega2560p-hal")]
     pub mod hal {
         pub mod power;
 
@@ -22,9 +24,14 @@ pub mod atmega2560p {
     }
 }
 
+#[cfg(feature = "atmega2560p")]
+pub use atmega2560p::*;
+
 /// Library for ATmega328P chip.
+#[cfg(feature = "atmega328p")]
 pub mod atmega328p {
     /// Hardware Abstraction Library (HAL).
+    #[cfg(feature = "atmega328p-hal")]
     pub mod hal {
         pub mod port;
 
@@ -40,5 +47,9 @@ pub mod atmega328p {
     }
 }
 
+#[cfg(feature = "atmega328p")]
+pub use atmega328p::*;
+
+pub mod avr;
 pub mod config;
 pub mod delay;
